kdiagram.plot.evaluation.plot\_polar\_confusion\_matrix\_in
===========================================================

.. currentmodule:: kdiagram.plot.evaluation

.. autofunction:: plot_polar_confusion_matrix_in